==> rhq-enterprise-server-4.6.0-sources.jar: org/rhq/enterprise/server/rest/domain/AlertNotificationRest.java <==
/*
 * RHQ Management Platform
 * Copyright (C) 2005-2013 Red Hat, Inc.
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */

package org.rhq.enterprise.server.rest.domain;

import java.util.HashMap;
import java.util.Map;

import javax.xml.bind.annotation.XmlRootElement;

import com.wordnik.swagger.annotations.ApiClass;
import com.wordnik.swagger.annotations.ApiProperty;

/**
 * Representation of notifications
 * @author Heiko W. Rupp
 */
@ApiClass("Represents an alert notification definition")
@XmlRootElement(name = "notification")
public class AlertNotificationRest {

    private int id;
    private String senderName;
    private Map<String,Object> config = new HashMap<String, Object>();

    public AlertNotificationRest() {
    }

    @ApiProperty("Id of the definition. This will change if the notification is updated.")
    public int getId() {
        return id;
    }

    public void setId(int id) {
        this.id = id;
    }

    @ApiProperty("A name taken from the <short-name> field of the plugin descriptor")
    public String getSenderName() {
        return senderName;
    }

    public void setSenderName(String senderName) {
        this.senderName = senderName;
    }

    @ApiProperty("Configuration that needs to be passed to the definition.")
    public Map<String, Object> getConfig() {
        return config;
    }

    public void setConfig(Map<String, Object> config) {
        this.config = config;
    }
}

==> rhq-enterprise-server-4.13.0-sources.jar: org/rhq/enterprise/server/rest/domain/AlertNotificationRest.java <==
/*
 * RHQ Management Platform
 * Copyright (C) 2005-2013 Red Hat, Inc.
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */

package org.rhq.enterprise.server.rest.domain;

import java.util.HashMap;
import java.util.Map;

import javax.xml.bind.annotation.XmlRootElement;

import com.wordnik.swagger.annotations.ApiClass;
import com.wordnik.swagger.annotations.ApiProperty;

/**
 * Representation of notifications
 * @author Heiko W. Rupp
 */
@ApiClass("Represents an alert notification definition")
@XmlRootElement(name = "notification")
public class AlertNotificationRest {

    private int id;
    private String senderName;
    private Map<String,Object> config = new HashMap<String, Object>();
    private Map<String, Object> extraConfig = new HashMap<String, Object>();

    public AlertNotificationRest() {
    }

    @ApiProperty("Id of the definition. This will change if the notification is updated.")
    public int getId() {
        return id;
    }

    public void setId(int id) {
        this.id = id;
    }

    @ApiProperty("A name taken from the <short-name> field of the plugin descriptor")
    public String getSenderName() {
        return senderName;
    }

    public void setSenderName(String senderName) {
        this.senderName = senderName;
    }

    @ApiProperty("Configuration that needs to be passed to the definition.")
    public Map<String, Object> getConfig() {
        return config;
    }

    public void setConfig(Map<String, Object> config) {
        this.config = config;
    }

    public void setExtraConfig(Map<String, Object> extraConfig) {
        this.extraConfig = extraConfig;
    }

    public Map<String, Object> getExtraConfig() {
        return extraConfig;
    }
}
